Learn R Programming

STICr (version 1.1.2)

get_calibration: get_calibration

Description

This is a function to fit specific conductivity (SpC) standards and uncalibrated conductivity measured by the STIC to a model object. This model can then be used to predict SpC values using apply_calibration. As of right now, only linear models are supported.

Usage

get_calibration(calibration_data)

Value

A fitted lm model object relating SpC to the uncalibrated conductivity values measured by the STIC

Arguments

calibration_data

STIC calibration data frame with columns "standard" (units: µS/cm) and "condUncal" (units: lux).

Examples

Run this code
head(calibration_standard_data)
lm_calibration <- get_calibration(calibration_standard_data)
summary(lm_calibration)

Run the code above in your browser using DataLab