a tidied data frame with the following column names: datetime, condUncal (uncalibrated conductivity, units: lux), tempC (temperature, units: degrees Celsius).
Arguments
infile
filename (including path or URL if needed) for a raw CSV file exported from HOBOware.
outfile
filename (including path if needed) to save the tidied data frame. Defaults to FALSE, in which case tidied data will not be saved.
convert_utc
a logical argument indicating whether the user would like to convert from the time zone associated with their CSV to UTC