Learn R Programming

STICr (version 1.1.2)

trim_hobo_data: trim_hobo_data

Description

This function trims a tidied hobo data frame by datetime to eliminate periods where the logger wad recording but not placed in the stream network

Usage

trim_hobo_data(
  stic_data,
  time_start = "2021-07-16 18:00:00",
  time_end = "2021-07-27 01:00:00"
)

Value

a tidied data frame with the same columns as the input, but trimmed to the user-defined time

Arguments

stic_data

A data frame with columns named condUncal and datetime, for example as produced by the function tidy_hobo_data.

time_start

User enters the time at which the logger was placed in the stream network

time_end

User enters the time at which the logger was removed from the stream network

Examples

Run this code
trimmed_data <-
  trim_hobo_data(tidy_stic_data,
    time_start = "2021-07-16 18:00:00",
    time_end = "2021-07-27 01:00:00"
  )
head(trimmed_data)

Run the code above in your browser using DataLab